Learn R Programming

aop (version 1.0.0)

calculate_confidence_and_median: Calculate the confidence envelope and the median for the bootstrap metaregression concentration response models.

Description

Calculates the 95 concentration-response data.

Usage

calculate_confidence_and_median(bootstrap_metaregression_obj)

Arguments

bootstrap_metaregression_obj
the object that contains the bootstrap metaregression models as a bmr object.

Value

bmr_obj a bmr object that holds all of the bootstrap metaregression models produced.

Details

This is an internal function that calculates the 95 the median for concentration-response data. It is called by the bootstrap_metaregression function.

Examples

Run this code
bmr_obj <- bootstrap_metaregression(oxybenzone, 15, 100)

Run the code above in your browser using DataLab